/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ghidra.trace.model.program;

import ghidra.trace.model.guest.TracePlatform;

public interface TraceVariableSnapProgramView extends TraceProgramView {
	/**
	 * Seek to a particular snap
	 * 
	 * @param snap the snap
	 */
	void setSnap(long snap);

	/**
	 * Seek to the latest snap
	 */
	default void seekLatest() {
		setSnap(getMaxSnap());
	}

	/**
	 * Set the current platform, so that actions have context
	 * 
	 * @param platform the platform
	 */
	void setPlatform(TracePlatform platform);
}
